@@ -1,7 +1,9 @@
+// Copyright Contributors to the Open Cluster Management project
+
 package apis
 
 import (
-	v1 "github.com/stolostron/cert-policy-controller/pkg/apis/policies/v1"
+	v1 "github.com/open-cluster-management/cert-policy-controller/pkg/apis/policies/v1"
 )
 
 func init() {
