@@ -1,7 +1,9 @@
+// Copyright Contributors to the Open Cluster Management project
+
 package controller
 
 import (
-	"github.com/stolostron/cert-policy-controller/pkg/controller/certificatepolicy"
+	"github.com/open-cluster-management/cert-policy-controller/pkg/controller/certificatepolicy"
 )
 
 func init() {
