@@ -4,6 +4,7 @@
 // Use, duplication or disclosure restricted by GSA ADP Schedule
 // Contract with IBM Corp.
 // Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 package certificatepolicy
 
@@ -16,9 +17,9 @@ import (
 	"strings"
 	"time"
 
-	policyv1 "github.com/stolostron/cert-policy-controller/pkg/apis/policies/v1"
-	"github.com/stolostron/cert-policy-controller/pkg/common"
-	"github.com/stolostron/cert-policy-controller/pkg/controller/util"
+	policyv1 "github.com/open-cluster-management/cert-policy-controller/pkg/apis/policies/v1"
+	"github.com/open-cluster-management/cert-policy-controller/pkg/common"
+	"github.com/open-cluster-management/cert-policy-controller/pkg/controller/util"
 	corev1 "k8s.io/api/core/v1"
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -349,7 +350,7 @@ func checkSecrets(policy *policyv1.CertificatePolicy, namespace string) (bool, u
 	}
 	//GOAL: Want the label selector to find secrets with certificates only!! -> is-certificate
 	// Loops through all the secrets within the CertificatePolicy's specified namespace
-	secretList, _ := (*common.KubeClient).CoreV1().Secrets(namespace).List(
+	secretList, _ := (*common.KubeClient).CoreV1().Secrets(namespace).List(context.TODO(),
 		metav1.ListOptions{LabelSelector: labels.Set(policy.Spec.LabelSelector).String()})
 	for _, secretItem := range secretList.Items {
 		secret := secretItem
