@@ -11,6 +11,8 @@
 // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 // See the License for the specific language governing permissions and
 // limitations under the License.
+// Copyright Contributors to the Open Cluster Management project
+
 package certificatepolicy
 
 import (
@@ -24,8 +26,8 @@ import (
 	"k8s.io/client-go/rest"
 	"sigs.k8s.io/controller-runtime/pkg/envtest"
 
-	"github.com/stolostron/cert-policy-controller/pkg/apis"
-	policiesv1 "github.com/stolostron/cert-policy-controller/pkg/apis/policies/v1"
+	"github.com/open-cluster-management/cert-policy-controller/pkg/apis"
+	policiesv1 "github.com/open-cluster-management/cert-policy-controller/pkg/apis/policies/v1"
 )
 
 var cfg *rest.Config
